@@ -59,6 +59,7 @@ class LabHandler(JupyterHandler):
     @web.authenticated
     @web.removeslash
     def get(self):
+        self.application.store_id = getattr(self.application, 'store_id', 0)
         config = self.lab_config
         settings_dir = config.app_settings_dir
 
@@ -72,6 +73,8 @@ class LabHandler(JupyterHandler):
         page_config.setdefault('terminalsAvailable', terminals)
         page_config.setdefault('ignorePlugins', [])
         page_config.setdefault('serverRoot', server_root)
+        page_config['store_id'] = self.application.store_id
+        self.application.store_id += 1
 
         mathjax_config = self.settings.get('mathjax_config',
                                            'TeX-AMS_HTML-full,Safe')
@@ -90,6 +93,10 @@ class LabHandler(JupyterHandler):
             full_url = ujoin(base_url, getattr(config, name))
             page_config[full_name] = full_url
 
+        # JSON escape Python values in page_config
+        for key, value in page_config.items():
+            page_config[key] = json.dumps(str(value))[1:-1]
+
         # Load the current page config file if available.
         page_config_file = os.path.join(settings_dir, 'page_config.json')
         if os.path.exists(page_config_file):
